summaryrefslogtreecommitdiffstats
path: root/chrome/browser/history/url_database.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/history/url_database.h')
-rw-r--r--chrome/browser/history/url_database.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/chrome/browser/history/url_database.h b/chrome/browser/history/url_database.h
index 36bfebb..49bf5f0 100644
--- a/chrome/browser/history/url_database.h
+++ b/chrome/browser/history/url_database.h
@@ -138,10 +138,12 @@ class URLDatabase {
// Autocomplete --------------------------------------------------------------
// Fills the given array with URLs matching the given prefix. They will be
// sorted by typed count, then by visit count, then by visit date (most
// recent first) up to the given maximum number. Called by HistoryURLProvider.
void AutocompleteForPrefix(const string16& prefix,
size_t max_results,
+ bool typed_only,
std::vector<URLRow>* results);
// Tries to find the shortest URL beginning with |base| that strictly
@@ -218,6 +220,9 @@ class URLDatabase {
// Ensures the keyword search terms table exists.
bool InitKeywordSearchTermsTable();
+ // Creates the indices used for keyword search terms.
+ void CreateKeywordSearchTermsIndices();
+
// Deletes the keyword search terms table.
bool DropKeywordSearchTermsTable();
@@ -138,10 +138,12 @@ class URLDatabase {
// Autocomplete --------------------------------------------------------------
// Fills the given array with URLs matching the given prefix. They will be
- // sorted by typed count, then by visit count, then by visit date (most
- // recent first) up to the given maximum number. Called by HistoryURLProvider.
+ // sorted by typed count, then by visit count, then by visit date (most recent
+ // first) up to the given maximum number. If |typed_only| is true, only urls
+ // that have been typed once are returned. Called by HistoryURLProvider.
void AutocompleteForPrefix(const string16& prefix,
size_t max_results,